@@ -482,7 +482,7 @@ dialog_client_reparent(Client *c)
 }
 
 /*  Padding between dialog borders and area available */
-#define DIALOG_PADDING 4 
+#define DIALOG_PADDING 0 
 
 /*
  *  dialog_get_available_area()
@@ -708,10 +708,43 @@ dialog_init_geometry(Client *c)
 
   dbg("%s() - \n\t avail_x : %d\n\tavail_y : %d\n\tavail_width : %d"
       "\n\tavail_height %d\n\tbdr_south : %d\n\tbdr_west : %d"
-      "\n\tbdr_east : %d\n\tbdr_north : %d\n",
+      "\n\tbdr_east : %d\n\tbdr_north : %d\n gravity %i\n",
       __func__, 
       avail_x, avail_y, avail_width, avail_height,
-      bdr_south, bdr_west, bdr_east, bdr_north);
+      bdr_south, bdr_west, bdr_east, bdr_north, c->gravity);
+
+  switch (c->gravity)
+    {
+    case NorthGravity:
+      c->y += (bdr_north + avail_y);
+      break;
+    case NorthEastGravity:
+      c->y += (bdr_north + avail_y);
+      c->x -= (bdr_east + (w->dpy_width - (avail_x + avail_width)));
+      break;
+    case WestGravity:
+      c->x += (bdr_west + avail_x);
+      break;
+    case EastGravity:
+      c->x -= (bdr_east + (w->dpy_width - (avail_x + avail_width)));
+      break;
+    case SouthWestGravity:
+      c->y -= (bdr_south + (w->dpy_height - (avail_y + avail_height)));
+      c->x += (bdr_west + avail_x);
+      break;
+    case SouthGravity:
+      c->y -= (bdr_south + (w->dpy_height - (avail_y + avail_height)));
+      break;
+    case SouthEastGravity:
+      c->x -= (bdr_east + (w->dpy_width - (avail_x + avail_width)));
+      c->y -= (bdr_south + (w->dpy_height - (avail_y + avail_height)));
+      break;
+    case CenterGravity:
+    case NorthWestGravity:
+    case StaticGravity:
+    default:
+      break;
+    }
 
   /* Message Dialogs are free to postion/size where ever but can use totally  
    * offscreen request to position to window corners - see below
@@ -748,16 +781,17 @@ dialog_init_geometry(Client *c)
    *   + positioned at 0,0
    *   + positioned offscreen
    */
-  if ( (c->x - bdr_west) <= avail_x 
-       || (c->x + c->width + bdr_east + bdr_west) > (avail_x + avail_width))
+
+  if ( (c->x - bdr_west) < avail_x 
+       || (c->x + c->width + bdr_east) > (avail_x + avail_width))
     {
       dbg("%s() centering x pos\n", __func__);
       c->x = (avail_width  - (c->width + bdr_east + bdr_west))/2 
 	+ bdr_west + avail_x;
     }
 
-  if ( (c->y - bdr_north) <= avail_y
-       || (c->y + c->height + bdr_south + bdr_north) > (avail_y+avail_height))
+  if ( (c->y - bdr_north) < avail_y
+       || (c->y + c->height + bdr_south) > (avail_y+avail_height))
     {
       dbg("%s() centering y pos\n", __func__);
       c->y = (avail_height - (c->height + bdr_south + bdr_north))/2 + avail_y + bdr_north;
@@ -976,6 +1010,24 @@ dialog_client_button_press(Client *c, XButtonEvent *e)
   int offset_north = dialog_client_title_height(c);
   int offset_south = 0, offset_west = 0, offset_east = 0;
 
+   if (w->config->super_modal)
+     {
+       Client *p;
+
+       p = client_get_highest_transient(c, CLIENT_IS_MODAL_FLAG, NULL);
+
+       if (p && p != c)
+	 {
+	   MBList *button_item = client_get_button_list_item_from_event(c, e);
+	   /* In the precense of a modal transient dialog ignore 
+	    * certain buttons. 
+	    */
+	   if ((button_item && button_item->id == BUTTON_ACTION_HELP)
+	       || (button_item && button_item->id == BUTTON_ACTION_CLOSE))
+	     return;
+	 }
+     }
+
   dialog_client_get_offsets(c, &offset_east, &offset_south, &offset_west);
 
   switch (client_button_do_ops(c, e, FRAME_DIALOG, 
@@ -1234,10 +1286,14 @@ dialog_client_set_focus_next(Client *c)
 
   /* We dont have focus, therefore dont suggest what to focus next */
   if (w->focused_client != c)
-    return NULL;
+    {
+      dbg("%s we dont have focus\n", __func__); 
+      return NULL;
+    }
 
   if (c->next_focused_client && c != c->next_focused_client)
     {
+      dbg("%s setting focus to c->next_focused_client\n", __func__); 
       if (w->focused_client == c)
 	w->focused_client = NULL;
 
@@ -1245,6 +1301,7 @@ dialog_client_set_focus_next(Client *c)
     }
   else
     {
+      dbg("%s setting focus to visibe_main\n", __func__); 
       if (w->focused_client == c)
 	w->focused_client = NULL;
       return wm_get_visible_main_client(w);
