@@ -180,7 +180,11 @@ ewmh_handle_root_message(Wm *w, XClientMessageEvent *e)
 	       if (parent != wm_get_visible_main_client(w))
 		 wm_activate_client(parent);
 	     }
-
+	   /* Likely activated by a TN so start pinging if aggresive setup */
+	   if (w->config->ping_aggressive 
+	       && c->type == MBCLIENT_TYPE_APP
+	       && c != wm_get_visible_main_client(w))
+	     ewmh_ping_client_start (c);
 	   wm_activate_client(c);
 	 }
        return 1;
@@ -698,6 +702,7 @@ ewmh_hung_app_check(Wm *w)
 	  */
 	  e.xclient.data.l[1] = c->window;
 	  XSendEvent(w->dpy, c->window, False, 0, &e);
+	  XSync(w->dpy, False);
 
 	  c->pings_sent++;
 
