@@ -78,6 +78,10 @@ static struct frame_lookup_t
   { "dialog-east",   FRAME_DIALOG_EAST  },
   { "dialog-west",   FRAME_DIALOG_WEST  },
   { "dialog-south",  FRAME_DIALOG_SOUTH },
+  { "dialog-nt-north",  FRAME_DIALOG_NT_NORTH },
+  { "dialog-nt-east",   FRAME_DIALOG_NT_EAST  },
+  { "dialog-nt-west",   FRAME_DIALOG_NT_WEST  },
+  { "dialog-nt-south",  FRAME_DIALOG_NT_SOUTH },
   { "utility-min",   FRAME_UTILITY_MIN  },
   { "utility-max",   FRAME_UTILITY_MAX  },
   { "menu",          FRAME_MENU         },
@@ -297,11 +301,12 @@ theme_frame_button_paint(MBTheme *theme,
 		{
 		  img_backing = mb_pixbuf_img_rgb_new(pb, button_w, button_h);
 
-		  mb_pixbuf_img_copy(pb, img_backing,
-				     theme->img_caches[frame_type],
-				     button_x, button_y,
-				     button_w, button_h,
-				     0, 0 );
+		  if (!theme->disable_pixbuf_cache)
+		    mb_pixbuf_img_copy(pb, img_backing,
+				       theme->img_caches[frame_type],
+				       button_x, button_y,
+				       button_w, button_h,
+				       0, 0 );
 
 		}
 
@@ -384,6 +389,17 @@ theme_has_message_decor( MBTheme *theme )
     return True;
 }
 
+Bool
+theme_has_borders_only_decor( MBTheme *theme )
+{
+  MBThemeFrame *frame = (MBThemeFrame *)list_find_by_id(theme->frames, 
+							FRAME_DIALOG_NT_NORTH);
+  if (frame == NULL) 
+    return False;
+  else
+    return True;
+}
+
 static void
 _theme_paint_gradient(MBTheme*       theme, 
 		      MBThemeLayer*  layer_cur, 
@@ -585,6 +601,9 @@ theme_frame_paint( MBTheme *theme,
   MBDrawable       *drawable = NULL;
   MBPixbuf         *pixbuf = w->pb;
 
+  if (dw == 0 || dh == 0)
+    return False;
+
   frame = (MBThemeFrame *)list_find_by_id(theme->frames, frame_type);
 
   if (frame == NULL) return False;
@@ -600,16 +619,19 @@ theme_frame_paint( MBTheme *theme,
     {
     case FRAME_MAIN_SOUTH:
     case FRAME_DIALOG_SOUTH:
+    case FRAME_DIALOG_NT_SOUTH:
     case FRAME_MSG_SOUTH:
       decor_idx = SOUTH;
       break;
     case FRAME_MAIN_EAST: 
     case FRAME_DIALOG_EAST:
+    case FRAME_DIALOG_NT_EAST:
     case FRAME_MSG_EAST:
       decor_idx = EAST;
       break;
     case FRAME_MAIN_WEST: 
     case FRAME_DIALOG_WEST:
+    case FRAME_DIALOG_NT_WEST:
     case FRAME_MSG_WEST:
       decor_idx = WEST;
       break;
@@ -747,7 +769,8 @@ theme_frame_paint( MBTheme *theme,
   
   if (c->backing_masks[MSK_NORTH] != None &&
       ( frame_type == FRAME_MAIN || frame_type == FRAME_DIALOG 
-	|| frame_type == FRAME_MSG || frame_type == FRAME_DIALOG_NORTH)
+	|| frame_type == FRAME_MSG || frame_type == FRAME_DIALOG_NORTH
+	|| frame_type == FRAME_DIALOG_NT_NORTH)
       )
     mb_pixbuf_img_render_to_mask(theme->wm->pb, img, 
 				 c->backing_masks[MSK_NORTH],
@@ -755,7 +778,8 @@ theme_frame_paint( MBTheme *theme,
   
   if (c->backing_masks[MSK_SOUTH] != None  &&
       ( frame_type == FRAME_MAIN_SOUTH || frame_type == FRAME_DIALOG_SOUTH 
-	|| frame_type == FRAME_MSG_SOUTH )
+	|| frame_type == FRAME_MSG_SOUTH 
+	|| frame_type == FRAME_DIALOG_NT_SOUTH)
       )
     mb_pixbuf_img_render_to_mask(theme->wm->pb, img, 
 				 c->backing_masks[MSK_SOUTH],
@@ -763,7 +787,7 @@ theme_frame_paint( MBTheme *theme,
   
   if (c->backing_masks[MSK_EAST] != None  &&
       ( frame_type == FRAME_MAIN_EAST || frame_type == FRAME_DIALOG_EAST 
-	|| frame_type == FRAME_MSG_EAST )
+	|| frame_type == FRAME_MSG_EAST || frame_type == FRAME_DIALOG_NT_EAST)
       )
     mb_pixbuf_img_render_to_mask(theme->wm->pb, img, 
 				 c->backing_masks[MSK_EAST],
@@ -771,7 +795,7 @@ theme_frame_paint( MBTheme *theme,
   
   if (c->backing_masks[MSK_WEST] != None  &&
       ( frame_type == FRAME_MAIN_WEST || frame_type == FRAME_DIALOG_WEST 
-	|| frame_type == FRAME_MSG_WEST )
+	|| frame_type == FRAME_MSG_WEST || frame_type == FRAME_DIALOG_NT_WEST )
       )
     mb_pixbuf_img_render_to_mask(theme->wm->pb, img, 
 				 c->backing_masks[MSK_WEST],
@@ -784,7 +808,7 @@ theme_frame_paint( MBTheme *theme,
   
   /* No point caching frame images which dont have buttons */
   
-  if (decor_idx != NORTH)
+  if (decor_idx != NORTH || theme->disable_pixbuf_cache == True)
     theme_img_cache_clear (theme, frame_type);
   
   /* Now paint text onto pixmap */
@@ -815,6 +839,10 @@ theme_frame_paint( MBTheme *theme,
 			     (c->name_is_utf8) ? MB_ENCODING_UTF8 : MB_ENCODING_LATIN,
 			     text_render_opts);
       dbg("%s() rendered text\n", __func__);
+
+      /* FIXME: we really need an mb_font_unset_color() here..? */
+      mb_col_unref(layer_label->label->col);
+      layer_label->label->font->col = NULL;
     }
 
   /* Finally put the drawable on the decoration frame background */
@@ -929,6 +957,8 @@ _theme_frame_menu_paint_text_entry(MBTheme      *theme,
 			 (entry->name_is_utf8) ? 
 			    MB_ENCODING_UTF8 : MB_ENCODING_LATIN,
 			 MB_FONT_RENDER_OPTS_CLIP_TRAIL);
+
+  mb_col_unref(color); 	/* set_color refs */
 }
 
 void
@@ -2199,6 +2229,7 @@ mbtheme_new (Wm *w)
   
   t->have_toolbar_panel = False;
   
+
   return t;
 }
 
@@ -2492,6 +2523,13 @@ mbtheme_init (Wm   *w,
      }       
 
    w->mbtheme = mbtheme_new(w);
+
+   if (get_attr(root_node, "cache") 
+       && !strcasecmp(get_attr(root_node, "cache"), "false"))
+     {
+       if (!getenv("MB_THEME_ALWAYS_CACHE"))
+	 w->mbtheme->disable_pixbuf_cache = True;
+     }
    
    for(n = root_node->kids; n != NULL; n = n->next)
    {
