@@ -1440,6 +1440,7 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
         * - eg toolbar/panel/input windows may dissapear and make
         *      more space available. 
         */
+
        if (e->width && (value_mask & CWWidth) 
 	   && e->width != c->width && e->width != c->init_width)
 	 c->init_width = e->width;
@@ -1490,6 +1491,17 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
 
 	   dialog_constrain_geometry(c, &req_x, &req_y, &req_w, &req_h);
 
+#ifdef USE_ALT_INPUT_WIN
+	 /* Alternate Input windows use the dialog type to 
+	  * fit in with stacking etc but they cant change width,x
+	  */
+	 if (c->flags & (CLIENT_TB_ALT_TRANS_FOR_DIALOG
+	                   |CLIENT_TB_ALT_TRANS_FOR_APP))
+	   {
+	     req_w = c->init_width = c->width;
+	     req_x = c->x;
+	   }
+#endif
 	   if (c->width == req_w && c->height == req_h)
 	     want_fake_configure = True; 
 
@@ -1497,16 +1509,11 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
 	   if (c->width != req_w)
 	     client_buttons_delete_all(c);
 
-	   /* TODO: fix composite for this */
-	   // comp_engine_client_hide(c->wm, c);
-	   
 	   xwc.width  = c->width  = req_w;
 	   xwc.height = c->height = req_h;
 	   xwc.x      = c->x      = req_x;
 	   xwc.y      = c->y      = req_y; 
 
-	   dbg("GRAVITY: x:%i y:%i\n", c->x, c->y);
-
 	   /* ICCCM says if window only moved - not size change,
             * then we send a fake one too.
 	    */
